/**
 * Created by janis dähne.
 */

import * as React from "react";
import {connect} from "react-redux";
import {bindActionCreators, Dispatch} from "redux";
import {returntypeof} from 'react-redux-typescript';
import {RootState} from "../../state/reducers";
import {Icon} from "semantic-ui-react";
import SiteHeaderUserArea from './siteHeaderUserArea'
import {setIsSiteHeaderBarCollapsed, setIsSiteMenuOpen} from "../../state/actions/siteHeaderBarActions";
import RelatedLinksView from './relatedLinksView'
import {withRouter} from "react-router";
import {HelpPopup} from '../helpers/helpPopup'
import {
  setClickedOnLocalServerMessage,
  setClickedOnServerMessage
} from '../../state/actions/globalSystemSettings/globalSystemSettingsActions'
import {getI18n} from '../../../i18n/i18nRoot'
import {plainTextToHtmlPlainFilter} from '../../helpers/stringHelper'

//const css = require('./styles.styl');

export interface MyProps {
  //readonly test: string
}

const mapStateToProps = (rootState: RootState /*, props: MyProps*/) => {
  return {
    //test0: rootState...
    //test: props.test
    siteMenuIsOpen: rootState.siteHeaderBarState.isSiteMenuOpen,
    isDisplayedAndEnabled: rootState.siteHeaderBarState.isSiteHeaderBarDisplayedAndEnabled,
    isSiteHeaderBarCollapsed: rootState.siteHeaderBarState.isSiteHeaderBarCollapsed,
    serverMessage: rootState.globalSystemSettingsState.serverMessage,
    localServerMessage: rootState.globalSystemSettingsState.localServerMessage,
    clickedOnServerMessage: rootState.globalSystemSettingsState.clickedOnServerMessage,

    clickedOnLocalServerMessage: rootState.globalSystemSettingsState.clickedOnLocalServerMessage,

    langId: rootState.i18nState.langId,
  }
}

const mapDispatchToProps = (dispatch: Dispatch) => bindActionCreators({
                                                                        //imported reducer funcs here
                                                                        setIsSiteMenuOpen,
                                                                        setIsSiteHeaderBarCollapsed,
                                                                        setClickedOnServerMessage,
                                                                        setClickedOnLocalServerMessage,
                                                                      }, dispatch)


const stateProps = returntypeof(mapStateToProps);
const dispatchProps = returntypeof(mapDispatchToProps);
type Props = typeof stateProps & typeof dispatchProps;

class SiteHeaderBar extends React.Component<Props, any> {

  siteMenuOpened(): void {
    this.props.setIsSiteMenuOpen(true)
  }

  siteMenuClosed(): void {
    this.props.setIsSiteMenuOpen(false)
  }


  render(): JSX.Element {

    return (
      <div>
        {
          this.props.isDisplayedAndEnabled &&
          !this.props.isSiteHeaderBarCollapsed &&
          <div className="site-header-bar flexed card-shadow">
            <div className="site-header-bar--location flexed">
              <div className="mar-right clickable" onClick={() => {
                this.props.setIsSiteMenuOpen(!this.props.siteMenuIsOpen)
              }}>

                <Icon size="big" name="sidebar"></Icon>
              </div>

              <RelatedLinksView/>
            </div>

            <div className="site-header-bar--status flexed">
              {
                //display server messages (local and from server)
              }
              {
                this.props.localServerMessage &&
                <div
                  className={!this.props.clickedOnLocalServerMessage ? 'exclamation-triangle-warning-animation mar-right' : 'mar-right'}
                  onClick={() => {
                    this.props.setClickedOnLocalServerMessage()
                  }}>
                  <HelpPopup wide icon="wifi"
                             defaultText={
                               <div style={{wordBreak: 'break-word'}}
                                    dangerouslySetInnerHTML={{__html: plainTextToHtmlPlainFilter(this.props.localServerMessage)}}>
                               </div>
                             }
                             additionalText={!this.props.clickedOnLocalServerMessage ? getI18n(this.props.langId, "You can click on the icon to disable its animation/change the color to normal for this session") : undefined}
                  />
                </div>
              }
              {
                this.props.serverMessage &&
                <div
                  className={!this.props.clickedOnServerMessage ? 'exclamation-triangle-warning-animation mar-right' : 'mar-right'}
                  onClick={() => {
                  this.props.setClickedOnServerMessage()
                }}>
                  <HelpPopup wide icon="exclamation triangle"
                             defaultText={
                               <div style={{wordBreak: 'break-word'}}
                                    dangerouslySetInnerHTML={{__html: plainTextToHtmlPlainFilter(this.props.serverMessage)}}>
                               </div>
                             }
                             additionalText={!this.props.clickedOnServerMessage ? getI18n(this.props.langId, "You can click on the icon to disable its animation/change the color to normal for this session") : undefined}
                  />
                </div>
              }
            </div>

            <div className="site-header-bar--user-area">
              <SiteHeaderUserArea></SiteHeaderUserArea>
            </div>

            <div className="site-menu-collapse-arrow arrow-up" onClick={() => {
              this.props.setIsSiteHeaderBarCollapsed(true)
            }}>
            </div>

          </div>
        }

        {
          this.props.isDisplayedAndEnabled &&
          this.props.isSiteHeaderBarCollapsed &&
          <div className="site-menu-expand-arrow arrow-down" onClick={() => {
            this.props.setIsSiteHeaderBarCollapsed(false)
          }}>
          </div>
        }
      </div>
    )
  }
}

export default withRouter(connect(mapStateToProps, mapDispatchToProps)(SiteHeaderBar))